package com.cmvr.aima.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.cmvr.aima.domain.AimaTask;
import com.cmvr.aima.domain.vo.AimaTaskVo;

/**
 * 爱玛任务管理Mapper接口
 * 
 * @author cmvr-iot
 * @since 2026-06-22
 */
public interface AimaTaskMapper extends BaseMapper<AimaTask> {
    /**
     * 查询爱玛任务管理
     * 
     * @param id 爱玛任务管理主键
     * @return 爱玛任务管理
     */
    AimaTask selectAimaTaskById(String id);

    /**
     * 查询爱玛任务管理列表
     * 
     * @param aimaTask 爱玛任务管理
     * @return 爱玛任务管理集合
     */
    List<AimaTask> selectAimaTaskList(AimaTask aimaTask);

    /**
     * 查询爱玛任务视图列表（包含关联信息）
     * 
     * @param aimaTask 爱玛任务管理
     * @return 爱玛任务视图集合
     */
    List<AimaTaskVo> selectAimaTaskVoList(AimaTask aimaTask);

    /**
     * 新增爱玛任务管理
     * 
     * @param aimaTask 爱玛任务管理
     * @return 结果
     */
    int insertAimaTask(AimaTask aimaTask);

    /**
     * 修改爱玛任务管理
     * 
     * @param aimaTask 爱玛任务管理
     * @return 结果
     */
    int updateAimaTask(AimaTask aimaTask);

    /**
     * 删除爱玛任务管理
     * 
     * @param id 爱玛任务管理主键
     * @return 结果
     */
    int deleteAimaTaskById(String id);

    /**
     * 批量删除爱玛任务管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteAimaTaskByIds(String[] ids);
}
